@@ -9,7 +9,11 @@ from vessel.steps import VaultInitStep, VaultSaveSecretsStep, GenerateKeysStep,
 from vessel.pipeline import Pipeline, Payload
 from vessel.logging import logger
 from vessel.version import VERSION
+import kubernetes
+from kubernetes.client.rest import ApiException
 
+LATEST_AGENT="1.2"
+LATEST_SENTINEL="1.2"
 
 def start(msg):
   click.echo(f"\n> {msg}...")
@@ -124,17 +128,16 @@ def register(ctx, token, cluster_host, cluster_ro, cluster_rw, vault, openshift,
 @main.command()
 @click.pass_context
 @click.argument('token')
-@click.option('--generate', is_flag=True, default=False, help="Regenerates yaml files [False]")
 @click.option('--dry', is_flag=True, default=False, help="Regenerates yaml files [False]")
-def deploy(ctx, token, generate, dry):
+def deploy(ctx, token, dry):
   """
   Deploy agent and sentinel for given TOKEN
   """
   click.echo('Debug is %s' % (ctx.obj['DEBUG'] and 'on' or 'off'))
   payload = Payload(token)
   pipeline = Pipeline(start_fn=start, end_fn=end, prompt_fn=prompt)
-  if generate:
-    pipeline.add(GenerateYamlStep())
+  pipeline.add(GenerateYamlStep())
+
   if not dry:
     pipeline.add(DeployAgentStep())
     pipeline.add(DeploySentinelStep())
@@ -146,3 +149,52 @@ def deploy(ctx, token, generate, dry):
     logger.error(e)
     if ctx.obj['DEBUG']:
       raise e
+
+@main.command()
+@click.pass_context
+@click.argument('token')
+@click.option('--agent-tag', default='latest', help="Set image tag for agent deployment")
+@click.option('--sentinel-tag', default='latest', help="Set image tag for sentinel deployment")
+def update(ctx, token, sentinel_tag, agent_tag):
+  """
+  Updates agent and sentinel deployments
+  """
+  agent_deployment = token + '-agent'
+  namespace = 'daas'
+  click.echo('Agent deployment name is %s' % agent_deployment)
+  click.echo('Updating Sentinel and Agent...')
+
+  # init kube client
+  click.echo('Creating kubernetes client configuration...')
+  configuration = kubernetes.client.Configuration()
+  configuration.host = 'https://localhost:6443'
+  configuration.verify_ssl = False
+  # TODO: recuperare questo token da vault
+  # aprirti il os.path.expanduser(f"~/.daas/vault.json")
+  # li dentro hai username e password di vault da utente
+  # ti loggi su vault con quelle
+  # recuper il token di k8s
+  k8s_token = 'eyJhbGciOiJSUzI1NiIsImtpZCI6IiJ9.eyJpc3MiOiJrdWJlcm5ldGVzL3NlcnZpY2VhY2NvdW50Iiwia3ViZXJuZXRlcy5pby9zZXJ2aWNlYWNjb3VudC9uYW1lc3BhY2UiOiJkYWFzIiwia3ViZXJuZXRlcy5pby9zZXJ2aWNlYWNjb3VudC9zZWNyZXQubmFtZSI6ImRlZmF1bHQtdG9rZW4tZnJ0OWsiLCJrdWJlcm5ldGVzLmlvL3NlcnZpY2VhY2NvdW50L3NlcnZpY2UtYWNjb3VudC5uYW1lIjoiZGVmYXVsdCIsImt1YmVybmV0ZXMuaW8vc2VydmljZWFjY291bnQvc2VydmljZS1hY2NvdW50LnVpZCI6ImM0ZDQ0M2IyLWJmOTItNGQ0OS1iZGM5LWJiZjVlZDVkZjM5YiIsInN1YiI6InN5c3RlbTpzZXJ2aWNlYWNjb3VudDpkYWFzOmRlZmF1bHQifQ.WI5UTdoeRpv6E75rYoa7crxNzniqRRDcFeUwR-MPN7y7UM8PjhMpSkTKYafnwV6fOFb2vUDN9qSCwQHNTaKjiQwWQmk4RGfXKxmkWbp3fn8XCltahLjBVvKtr6ZwT0qXS8cL2LSWr5kKruhFzNDefZ8w515jK7zg8PAGtoMz-18sTzdYMfebLVjluPm2AqxFn0WmfDawhqi_UCV4FybUiWYtRLSv0n7SrjAK-xwfISgKamrIdz8x8mCOaQCQ5BrRZuArfJIAIHOy4XUjn5fEurbcql6DcS2aBrq7yfI6ElWG7bZuF4FlsGsntTh8kotesiQ9CbQJC1chr6kZvDACWg'
+  configuration.api_key = {"authorization": "Bearer " + k8s_token}
+  api_client = kubernetes.client.ApiClient(configuration)
+  apps = kubernetes.client.AppsV1Api(api_client)
+  
+  try:
+    body = {
+      "spec": {
+        "template": {
+          "spec": {
+            "containers": [
+              {
+                "name": "593aedda-657e-455b-9491-f774a5006de7-agent",
+                "image": "docker-registry.oc.corp.sourcesense.com/daas/workstation-agent:" + agent_tag
+                }
+            ]
+          }
+        }
+      }
+    }
+    api_response = apps.patch_namespaced_deployment(agent_deployment, namespace, body)
+    logger.debug(api_response)
+  except ApiException as e:
+    print("Exception when calling AppsV1Api->patch_namespaced_deployment: %s\n" % e)
\ No newline at end of file
