@@ -58,7 +58,8 @@ class GenerateYamlStep(Step):
 
   def _get_keys(self, payload:Payload) -> Tuple[str]:
     if payload.rsa:
-      return (payload.rsa, payload.vault_user, payload.vault_pwd, payload.distribution)
+      name = urllib.parse.quote(payload.cluster['result']['name'].lower().replace(" ", "-"))
+      return (name, payload.rsa, payload.vault_user, payload.vault_pwd, payload.distribution)
     else:
       with open(os.path.expanduser(f"~/.daas/{payload.token}/registration.json"), 'r') as f:
         registration = json.load(f)
@@ -197,7 +198,7 @@ class GenerateYamlStep(Step):
                         name: vault-secret
                         key: PWD
                   - name: ANCHORE_URL
-                    value: http://anchore-anchore-engine-api.anchore.svc:8228
+                    value: http://anchore-anchore-engine-api.anchore.svc:8228/anchore
                   - name: ANCHORE_USERNAME
                     value: admin
                   - name: ANCHORE_PWD
@@ -217,14 +218,27 @@ class GenerateYamlStep(Step):
             name: svc-{name}-sentinel
           spec:
             ports:
-            - name: 8000-tcp
-              port: 8000
+            - name: 8089-tcp
+              port: 8089
               protocol: TCP
-              targetPort: 8000
+              targetPort: 8089
             selector:
               app: {name}-sentinel
             sessionAffinity: None
             type: ClusterIP
+        - apiVersion: extensions/v1beta1
+          kind: Ingress
+          metadata:
+            name: {name}-sentinel-ingress
+          spec:
+            rules:
+            - host: {name}-sentinel.local
+              http:
+                paths:
+                - backend:
+                    serviceName: svc-{name}-sentinel
+                    servicePort: 8089
+                  path: /
         """
         ).format(**kwargs)
 
